var map;
var mapConfig = {
  zoom: 10,
  center: { lat: 19.076, lng: 72.8777 },
};

var locations = [
  {
    name: "The Gateway - Sewri, Mumbai",
    position: { lat: 18.992422506336847, lng: 72.85434730586488 },
    description:
      "L&T Realty Sales Office, Rafi Ahmed Kidwai Road, Opp Fatima High School, Gandhi Nagar, Sewri, Mumbai, India - 400015",
    imgSrc: "images/other-resident3.webp",
    link: "https://www.lntrealty.com/residences/the-gateway-3-4-bhk-flats-in-sewri/",
  },
  {
    name: "Island Cove - Mahim, Mumbai",
    position: { lat: 19.04353314045584, lng: 72.84191355709096 },
    description:
      "L&T Realty Sales Experience Gallery Near St.Michaels Church Mori Road Mahim Mumbai 400016",
    imgSrc: "images/other-resident3.webp",
    link: "https://www.lntrealty.com/residences/luxury-2-3-bhk-flats-in-island-cove-mahim-mumbai/",
  },
  {
    name: "L&amp;T Technology Center IV, Powai, Mumbai",
    position: { lat: 19.122888078124067, lng: 72.89240661584084 },
    description:
      "L&amp;T Technology Center, Next to L&amp;T Business Park, Off JVLR, Saki Vihar Road, Powai, Mumbai, India",
    imgSrc: "images/other-resident3.webp",
    link: "https://www.lntrealty.com/offices/lt-technology-center-iv-powai-mumbai/",
  },
];

function initGoogleMap() {
  console.log("Google Map is initializing...");
  var mapElement = document.getElementById("gmap");
  if (mapElement) {
    map = new google.maps.Map(mapElement, mapConfig);
    addMarkers();
  } else {
    console.error("Map element not found");
  }
}

function addMarkers() {
  var infoWindow = new google.maps.InfoWindow();

  locations.forEach(function (location) {
    var marker = new google.maps.Marker({
      position: location.position,
      map: map,
      title: location.name,
    });

    // Create the InfoWindow content
    var infoWindowContent = `
        <div class="mapInfoWindow">
          <a class="gmapInfoWindowClose" href="javascript:void(0)" class="close">X</a>
          <div class="content">
            <img class="image" src="${location.imgSrc}" alt="${location.name}" />
            <div class="info">
              <div class="title">${location.name}</div>
              <div class="desc">${location.description}</div>
              <div class="know-more-btn">
                <a href="${location.link}" target="_blank">VIEW PROJECT</a>
              </div>
            </div>
          </div>
        </div>
      `;

    // Add click listener for the marker
    marker.addListener("click", function () {
      console.log(`Marker clicked: ${location.name}`);
      console.log("InfoWindow content: ", infoWindowContent);
      infoWindow.setContent(infoWindowContent);
      infoWindow.open(map, marker);
      console.log("InfoWindow opened.");
    });
  });

  // Use event delegation to handle close button clicks
  google.maps.event.addListener(infoWindow, "domready", function () {
    const closeButton = document.querySelector(".gmapInfoWindowClose");
    if (closeButton) {
      closeButton.onclick = function () {
        infoWindow.close();
      };
    }
  });

  // Optionally, close the info window when the map is clicked
  map.addListener("click", function () {
    infoWindow.close();
  });
}
